/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: BaseBusinessDelegateMock.as 36 2011-06-20 14:38:41Z dangtran $
 *
 */

package org.ow2.sirocco.cloudmanager.business
{
	import mx.rpc.events.FaultEvent;
	import mx.rpc.IResponder;
	import flash.events.Event;
	import mx.rpc.events.ResultEvent;
	import flash.utils.Timer;
	import flash.events.TimerEvent;
	
	/**
	 *  This class is a base class for all business delegate mockups
	 *  extend this class to get asynchronous respond.
	 *  You must call the super(responder) in your business delegate constructor
	 *  You can set the latency time by call this.Latency = <milliseconds>
	 *  To activate your mockup you will need to change the relevant command and
	 *  call the xxxDelegateMock.
	 */
	public class BaseBusinessDelegateMock
	{
		// Responder of the delegate
		private var responder : IResponder;
		// Using a timer to simulate the latency during the client-server roundtrip
		private var timer:Timer;
		// The latency value can be set by the specific Business Delegates
		private var latency:Number = 0;  //the default value is no latency
		// Holds the results of the delegate call
		private var results:Object;

		public function BaseBusinessDelegateMock(responder:IResponder)
		{
			this.responder = responder;
		}
		
		protected function setResults(results:Object):void
		{
			this.results = results;
			if (latency > 0)
			{
				this.timer = new Timer(latency);
				timer.addEventListener("timer", invokeResponder);			
				timer.start();
			}
			else
			{
				invokeResponder(null);
			}
		}
		
		protected function set Latency(time:Number):void
		{
			this.latency = time;
		}
		
		private function invokeResponder(evt:TimerEvent):void
		{
			try
			{
				if (evt != null)
				{
					timer.stop();
				}
				var ev:ResultEvent = new ResultEvent("MockUp", false, true, results);
				responder.result(ev);
			}
			catch(er:Error)
			{
				responder.fault(new FaultEvent("MockUp"));
			}			
		}
	}
}
