/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: AuthenticateUserCommand.as 36 2011-06-20 14:38:41Z dangtran $
 *
 */

package org.ow2.sirocco.cloudmanager.command
{
import com.adobe.cairngorm.CairngormError;
import com.adobe.cairngorm.commands.*;
import com.adobe.cairngorm.control.*;
import org.ow2.sirocco.cloudmanager.business.*;
import org.ow2.sirocco.cloudmanager.vo.DbParametersVO;
import org.ow2.sirocco.cloudmanager.event.*;
import org.ow2.sirocco.cloudmanager.model.*;
import org.ow2.sirocco.cloudmanager.vo.ProjectVO;
import org.ow2.sirocco.cloudmanager.vo.UserVO;

import mx.controls.Alert;
import mx.managers.CursorManager;
import mx.resources.IResourceManager;
import mx.resources.ResourceManager;
import mx.rpc.IResponder;
import mx.rpc.events.ResultEvent;


public class AuthenticateUserCommand extends SequenceCommand implements IResponder
{
    
    private var username : String;
    
    private var password : String;
    
    private var model : OOCModelLocator = OOCModelLocator.getInstance();
    
    
    
    public function AuthenticateUserCommand()
    {
    }
    
    
    
    override public function execute(event : CairngormEvent) : void
    {
        // Set the "busy" cursor
        CursorManager.setBusyCursor();
        
        var delegate : AuthenticateUserDelegate = this.model.authenticateUserDelegate;
        delegate.responder = this;
        
        var authenticateUserEvent : AuthenticateUserEvent = event as AuthenticateUserEvent;
        username = authenticateUserEvent.username;
        password = authenticateUserEvent.password;
        
        // delegate to the AuthenticateUserDelegate to call the authenticate user service
        delegate.authenticateUser(username, password);
    }
    
    
    
    public function result(event : Object) : void
    {
        
        var resourceManager : IResourceManager = ResourceManager.getInstance();
        
        resourceManager.localeChain = [this.model.resourceManager.locale];
        
        CursorManager.removeAllCursors();
        
        var resultEvent : ResultEvent = event as ResultEvent;
        
        if (resultEvent.result is String)
        {
            // Result of the authenticateUser command
            this.model.sessionTokenId = resultEvent.result as String;
            
            var delegate : GetUserByUsernameDelegate = this.model.getUserByUsernameDelegate;
            delegate.responder = this;
            // delegate to the AuthenticateUserDelegate to call the authenticate user service
            delegate.getUserByUsername(username);
        }
        else if (resultEvent.result == null)
            displayAccessDeniedAlert();
        else
        {
            // Result of the getUserByUsername command
            var resultUserEvent : ResultEvent = event as ResultEvent;
            var userVo : UserVO = resultUserEvent.result as UserVO;
            var projectVo : ProjectVO;
            
            // set attributes in the model to update the UI
            this.model.userVo = userVo;
            this.model.username = userVo.username;
            this.model.isAdmin = userVo.admin;
            
            if (!this.model.isAdmin)
            {
                // Default project is loaded 
                projectVo = userVo.projectVoList.getItemAt(0) as ProjectVO;
                this.model.projectId = projectVo.projectId;
                this.model.projectName = projectVo.name;
            }
            
            DataPushListener.getInstance().connect();
            
            this.model.isLogged = true;
            
            var cEvent : CairngormEvent;
            cEvent = new GetDbParametersEvent();
            cEvent.dispatch();
            
            cEvent = new GetAllUsersEvent();
            cEvent.dispatch();
            
            if (!this.model.isAdmin)
            {
                cEvent = new GetVMImagesByProjectEvent();
                cEvent.dispatch();
                cEvent = new GetProjectsByUserEvent(this.model.username);
                cEvent.dispatch();
                cEvent = new GetVirtualMachinesByProjectEvent();
                cEvent.dispatch();
                cEvent = new GetDataCenterResourceTreeEvent();
                cEvent.dispatch();
            }
            else
            {
                cEvent = new GetAllVMImagesEvent();
                cEvent.dispatch();
                cEvent = new GetAllProjectsEvent();
                cEvent.dispatch();
            }
            
        }
    }
    
    
    
    /**
    * Manage failure : show the error message.
    */
    public function fault(event : Object) : void
    {
        CursorManager.removeAllCursors();
        
        this.model.onCommandFault(event);
    }
    
    
    
    private function displayAccessDeniedAlert() : void
    {
        Alert.show("Wrong password.", "Access denied");
    }
}
}
