/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: GetAllVMImagesCommand.as 151 2011-07-19 13:12:35Z otterley $
 *
 */

package org.ow2.sirocco.cloudmanager.command {

    import com.adobe.cairngorm.commands.*;
    import com.adobe.cairngorm.control.*;
    import org.ow2.sirocco.cloudmanager.business.*;
    import org.ow2.sirocco.cloudmanager.event.*;
    import org.ow2.sirocco.cloudmanager.model.*;
    import org.ow2.sirocco.cloudmanager.vo.VMImageVO;
    import org.ow2.sirocco.cloudmanager.vo.VirtualMachineVO;
    
    import mx.collections.ArrayCollection;
    import mx.controls.Alert;
    import mx.managers.CursorManager;
    import mx.messaging.messages.ErrorMessage;
    import mx.rpc.IResponder;
    import mx.rpc.events.FaultEvent;
    import mx.rpc.events.ResultEvent;

    public class GetAllVMImagesCommand extends SequenceCommand implements IResponder {

        override public function execute(event : CairngormEvent) : void {
        	// Set the "busy" cursor
            CursorManager.setBusyCursor();
            
            var model : OOCModelLocator = OOCModelLocator.getInstance();
            model.loadingVMImagesVoList = true;
        	
            var getAllVMImagesEvent : GetAllVMImagesEvent = event as GetAllVMImagesEvent;
            
            var delegate : GetAllVMImagesDelegate = OOCModelLocator.getInstance().getAllVMImagesDelegate;
            delegate.responder = this;

            delegate.getAllVMImages();
        }

        public function result(event : Object) : void {
            CursorManager.removeAllCursors();
            
            var resultEvent : ResultEvent = event as ResultEvent;
            var arrayCollection : ArrayCollection = resultEvent.result as ArrayCollection;
            
            // Gets the Model
            var model : OOCModelLocator = OOCModelLocator.getInstance();

            // set attributes in the model to update the UI
            //model.VMImagesList = arrayCollection;
            model.vmImagesVoList.source = arrayCollection.source;
            
            // Set the VMImage name of virtual machines
            for each (var virtualMachineVo:VirtualMachineVO in model.virtualMachinesVoList)
			{
				for each (var vmImageVo:VMImageVO in model.vmImagesVoList)
				{
					if (vmImageVo.id == virtualMachineVo.imageVmiId)
					{
						virtualMachineVo.imageName = vmImageVo.name;
						virtualMachineVo.vmImageVo = vmImageVo;
					}
				}

			}
            for each (var virtualMachineVoByUser:VirtualMachineVO in model.virtualMachinesVoByProjectList)
			{
				for each (var vmImageVoByUser:VMImageVO in model.vmImagesVoList)
				{
					if (vmImageVoByUser.id == virtualMachineVoByUser.imageVmiId)
					{
						virtualMachineVoByUser.imageName = vmImageVoByUser.name;
						virtualMachineVoByUser.vmImageVo = vmImageVoByUser;
					}
				}

			}

            model.loadingVMImagesVoList = false;
         }
         
         /**
         * Manage failure : show the error message.
         */
        public function fault(event : Object) : void {
            var model : OOCModelLocator = OOCModelLocator.getInstance();
            model.loadingVMImagesVoList = false;

            var modelLocator : OOCModelLocator = OOCModelLocator.getInstance();
            
            modelLocator.onCommandFault(event);
        }
    }
}
