/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: GetAllVirtualMachinesCommand.as 36 2011-06-20 14:38:41Z dangtran $
 *
 */

package org.ow2.sirocco.cloudmanager.command {

    import com.adobe.cairngorm.commands.*;
    import com.adobe.cairngorm.control.*;
    import org.ow2.sirocco.cloudmanager.business.*;
    import org.ow2.sirocco.cloudmanager.event.*;
    import org.ow2.sirocco.cloudmanager.model.*;
    import org.ow2.sirocco.cloudmanager.vo.VirtualMachineVO;
    
    import mx.collections.ArrayCollection;
    import mx.controls.Alert;
    import mx.managers.CursorManager;
    import mx.messaging.messages.ErrorMessage;
    import mx.rpc.IResponder;
    import mx.rpc.events.FaultEvent;
    import mx.rpc.events.ResultEvent;

    public class GetAllVirtualMachinesCommand extends SequenceCommand implements IResponder {

        override public function execute(event : CairngormEvent) : void {
        	// Set the "busy" cursor
            CursorManager.setBusyCursor();
            
            // Indicate Virtual Machines are being loaded
            OOCModelLocator.getInstance().loadingVirtualMachines = true;
        	
            var getAllVirtualMachinesEvent : GetAllVirtualMachinesEvent = event as GetAllVirtualMachinesEvent;
            
            var delegate : GetAllVirtualMachinesDelegate = OOCModelLocator.getInstance().getAllVirtualMachinesDelegate;
            delegate.responder = this;

            // delegate to the GetAllVirtualMachinesDelegate to call the method
            delegate.getAllVirtualMachines();
        }

        public function result(event : Object) : void {
            CursorManager.removeAllCursors();
            
            var resultEvent : ResultEvent = event as ResultEvent;
            var arrayCollection : ArrayCollection = resultEvent.result as ArrayCollection;
            
            // Gets the Model
            var model : OOCModelLocator = OOCModelLocator.getInstance();

            // set attributes in the model to update the UI
            //model.virtualMachinesList = arrayCollection;
            model.virtualMachinesVoList.source = arrayCollection.source;
            
            // Update the virtualMachineImage to set the image name in VirtualMachineVO
            var getAllVMImagesEvent:GetAllVMImagesEvent = new GetAllVMImagesEvent();
			getAllVMImagesEvent.dispatch();

            // Indicate Virtual Machines loading is finished
            OOCModelLocator.getInstance().loadingVirtualMachines = false;
         }
         
         /**
         * Manage failure : show the error message.
         */
        public function fault(event : Object) : void {
            CursorManager.removeAllCursors();

             var model : OOCModelLocator = OOCModelLocator.getInstance();
             
             model.onCommandFault(event);
        }
    }
}
