/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: GetVirtualMachinesByHostCommand.as 151 2011-07-19 13:12:35Z otterley $
 *
 */

package org.ow2.sirocco.cloudmanager.command
{

	import com.adobe.cairngorm.commands.*;
	import com.adobe.cairngorm.control.*;
	import org.ow2.sirocco.cloudmanager.business.*;
	import org.ow2.sirocco.cloudmanager.event.*;
	import org.ow2.sirocco.cloudmanager.model.*;
	import org.ow2.sirocco.cloudmanager.utils.ArrayCollectionUtils;
	import org.ow2.sirocco.cloudmanager.utils.logger.Logger;
	import org.ow2.sirocco.cloudmanager.vo.HostVO;
	import org.ow2.sirocco.cloudmanager.vo.VirtualMachineVO;

	import mx.collections.ArrayCollection;
	import mx.controls.Alert;
	import mx.rpc.IResponder;
	import mx.rpc.events.ResultEvent;

	public class GetVirtualMachinesByHostCommand extends SequenceCommand implements IResponder
	{

		private var hostId:String;

		public function GetVirtualMachinesByHostCommand()
		{
		}

		override public function execute(event:CairngormEvent):void
		{
			// Set the "busy" cursor
			//CursorManager.setBusyCursor();

			var model:OOCModelLocator=OOCModelLocator.getInstance();

			var cEvent:GetVirtualMachinesByHostEvent=event as GetVirtualMachinesByHostEvent;
			hostId=cEvent.hostId;

			var delegate:GetVirtualMachinesByHostDelegate=OOCModelLocator.getInstance().getVirtualMachinesByHostDelegate;
			delegate.responder=this;

			delegate.getVirtualMachinesByHost(hostId);
		}

		public function result(event:Object):void
		{
			var resultEvent:ResultEvent=event as ResultEvent;
			var arrayCollection:ArrayCollection=resultEvent.result as ArrayCollection;

			var model:OOCModelLocator=OOCModelLocator.getInstance();

			var hostEntry:Object=model.objResourceTable[hostId];
			if (hostEntry != null)
			{
				var objHost:Object=hostEntry.treenode;
				if (objHost == null)
				{
					Logger.debug("HostEntry broken");
					return;
				}
				ArrayCollection(objHost.children).removeAll();
				// Search the Virtual Machines into the existing Virtual Machine list
				// (in order to improve bindings)
				for each (var vm:VirtualMachineVO in arrayCollection.source)
				{
					var vmFromGlobalVirtualMachineList:VirtualMachineVO=ArrayCollectionUtils.findInCollection(model.virtualMachinesVoList, "id", vm.id) as VirtualMachineVO;
					if (vmFromGlobalVirtualMachineList == null)
					{
						// VM not found
						Logger.debug("VM not found: " + vm.id);
						Alert.show("VM not found: " + vm.id, model.resourceManager.common_error);
						// If not found, put the VM returned by the getVirtualMachinesByHost function
						ArrayCollection(objHost.children).addItem(vm);
					}
					else
					{
						ArrayCollection(objHost.children).addItem(vmFromGlobalVirtualMachineList);
					}
				}
				model.fullDataCenterResourceTreeUpdateWatcher++;
			}
			else
				Logger.debug("Received VM list for unknown Host id=" + hostId);

		}


		/**
		 * Manage failure : show the error message.
		 */
		public function fault(event:Object):void
		{
			//CursorManager.removeAllCursors();

			var model:OOCModelLocator=OOCModelLocator.getInstance();

			model.onCommandFault(event);
		}
	}
}
