/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: DisabledItemsList.as 36 2011-06-20 14:38:41Z dangtran $
 *
 */

package org.ow2.sirocco.cloudmanager.utils
{
import flash.events.MouseEvent;
import flash.ui.Keyboard;
import mx.controls.listClasses.IListItemRenderer;
import mx.controls.List;

/**
 *  A List that uses a disableFunction to determine if an item can be selected or not
 */
public class DisabledItemsList extends List
{
	public function DisabledItemsList() 
	{
		super();
	}

	/**
	 *  The function to apply that determines if the item is "disabled" or not.
	 *  Takes one argument, which is the data item
	 *  Returns true if item cannot be selected.
	 */
	public var disabledFunction:Function;

	override protected function mouseEventToItemRenderer(event:MouseEvent):IListItemRenderer
	{
		var listItem:IListItemRenderer = super.mouseEventToItemRenderer(event);
		if (listItem)
		{
			if (listItem.data)
			{
				if (disabledFunction(listItem.data))
				{
					return null;
				}
			}
		}
		return listItem;
	}

	private var selectionUpward:Boolean;

    override protected function moveSelectionVertically(code:uint, shiftKey:Boolean,
                                               ctrlKey:Boolean):void
    {
		if (code == Keyboard.DOWN)
			selectionUpward = false;
		else
			selectionUpward = true;
		super.moveSelectionVertically(code, shiftKey, ctrlKey);
	}

    override protected function finishKeySelection():void
	{
		super.finishKeySelection();
	
		var i:int;
        var uid:String;
        var rowCount:int = listItems.length;
        var partialRow:int = (rowInfo[rowCount-1].y + rowInfo[rowCount-1].height >
                                  listContent.height) ? 1 : 0;

		var listItem:IListItemRenderer;
        listItem = listItems[caretIndex - verticalScrollPosition][0];
        if (listItem)
        {
            if (listItem.data);
			{
				if (disabledFunction(listItem.data))
				{
					// find another visible item that is enabled
					// assumes there is one that is fully visible
					rowCount = rowCount - partialRow;
					var idx:int = caretIndex - verticalScrollPosition;
					if (selectionUpward)
					{
						// look up;
						for (i = idx - 1; i >= 0; i--)
						{
							listItem = listItems[i][0];
							if (!disabledFunction(listItem.data))
							{
								selectedIndex = i - verticalScrollPosition;
								return;
							}
						}
						for (i = idx + 1; i < rowCount; i++)
						{
							listItem = listItems[i][0];
							if (!disabledFunction(listItem.data))
							{
								selectedIndex = i - verticalScrollPosition;
								return;
							}
						}
					}
					else
					{
						// look down;
						for (i = idx + 1; i < rowCount; i++)
						{
							listItem = listItems[i][0];
							if (!disabledFunction(listItem.data))
							{
								selectedIndex = i - verticalScrollPosition;
								return;
							}
						}
						for (i = idx - 1; i >= 0; i--)
						{
							listItem = listItems[i][0];
							if (!disabledFunction(listItem.data))
							{
								selectedIndex = i - verticalScrollPosition;
								return;
							}
						}
					}
				}
			}
		}
	}
  
}

}
