/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: TextInputWithValidator.as 36 2011-06-20 14:38:41Z dangtran $
 *
 */

package org.ow2.sirocco.cloudmanager.view.component
{
	import flash.events.Event;
	import flash.geom.Point;
	
	import mx.controls.TextInput;
	import mx.controls.ToolTip;
	import mx.core.UIComponent;
	import mx.events.FlexEvent;
	import mx.managers.ToolTipManager;

	public class TextInputWithValidator extends TextInput
	
	{
		public function TextInputWithValidator()
		{
			super();
//			addEventListener(FocusEvent.FOCUS_IN, hideError);

			addEventListener(FlexEvent.HIDE, onHide);
			addEventListener(Event.REMOVED, onHide);
			addEventListener(Event.REMOVED_FROM_STAGE, onHide);
			addEventListener(Event.DEACTIVATE, onHide);
			addEventListener(FlexEvent.INVALID, onHide);
		}
		
		/*[Bindable]
		public function isReallyVisible():Boolean
		{
			var obj:UIComponent = this;
			while (obj != null)
			{
				if (obj.visible == false)
				{
					return false;
				}
				else
				{
					obj = obj.parent;
				}
			}
			
			return true;
		}*/
		
		private function onHide(evt:Event):void
		{
			hideError();
		}
		
	    // ==============================================================
	    //      style properties
	    // ==============================================================
	    /** Used to set the styleName on the error tootip */
	    public var errorStyle:String = "errorTip";
	    /**
	     * Allows for manual adjustment of the error tootip <code>x</code> position
	     **/
	    public var adjustErrorXPosition:Number = 0;
	    /**
	     * Allows for manual adjustment of the error tootip <code>y</code> position
	     **/
	    public var adjustErrorYPosition:Number = 0;
	
	    /** Adjusts the padding above the <code>errorText</code> string **/
	    public var errorPaddingTop:Number = 2;
	    /** Adjusts the padding below the <code>errorText</code> string **/
	    public var errorPaddingBottom:Number = 2;
	    /** Adjusts the padding to the left of the <code>errorText</code> string **/
	    public var errorPaddingLeft:Number = 2;
	    /** Adjusts the padding to the right of the <code>errorText</code> string **/
	    public var errorPaddingRight:Number = 2;
	
	    // ==============================================================
	    //      errorTipLocation
	    // ==============================================================
	
	    /** This property maps to <code>errorTipBorderStyle</code> in <code>ToolTipManager.createToolTip()</code> */
	    [Inspectable( enumeration = "errorTipAbove,errorTipBelow,errorTipRight")]
	    public var errorTipLocation:String = null;
	
	    // ==============================================================
	    //      private vars
	    // ==============================================================
	    /** Flag to indicate if the error tootip has already been created */
	    private var _toolTipExists:Boolean = false;
	
	    /** The error tootip that displays when the <code>errorText</code> property is populated */
	    private var errorTip:ToolTip;
	
	    private var _errorText:String = "";
	    /** 
	     * Populate with the string you would like displayed in the error tootip,
	     * Dispaly of Error tootip is triggered when errorText is populated,
	     * Set errorText to "" to hide/destroy the error tootip
	     * 
	     * @default ""
	    */
	    [Bindable]
	    public function get errorText():String
	    {
	        return _errorText;
	    }
	    public function set errorText( errorText:String ):void
	    {
	        if( _errorText != errorText && errorText != null )
	        {
	            _errorText = errorText;
	        }
	        showError();
	    }
	
	    // ==============================================================
	    //      private functions
	    // ==============================================================
	
	    /**
	    * @private
	    * Handles the display of the error tootip and the population of style properties.
	    */
	    protected function showError():void
	    {
	        if( !_toolTipExists && (_errorText != null) && (_errorText != ""))
	        {
	            var pt:Point = new Point(0, 0);
	            pt = this.contentToGlobal(pt);
	
	            errorTip = ToolTipManager.createToolTip(_errorText, pt.x + this.width + adjustErrorXPosition, pt.y + adjustErrorYPosition, errorTipLocation) as ToolTip;
	
	            // Check if errorTipLocation is set, otherwise setting styleName will override.
	            if( errorTipLocation == null )
	            {
	                errorTip.setStyle("styleName", errorStyle);
	            }
	
	            errorTip.setStyle("paddingTop", errorPaddingTop);
	            errorTip.setStyle("paddingBottom", errorPaddingBottom);
	            errorTip.setStyle("paddingRight", errorPaddingLeft);
	            errorTip.setStyle("paddingRight", errorPaddingRight);
	
	            errorTip.id = this.name;

	            this.styleName = "error";
	
	            _toolTipExists = true;
	        }
	        else if( _toolTipExists && (/*(_errorText == null) ||*/ (_errorText == '')))
	        {
	            hideError();

	            this.styleName = null;
	        }
	    }
	
	    /**
	    * Handles the hiding of the error tootip, Triggered when <code>errorText</code> is set to ""
	    * @private
	    */
	    public function hideError( event:Event = null ):void
	    {
	        if( _toolTipExists )
	        {
	            ToolTipManager.destroyToolTip( errorTip );
	            _toolTipExists = false;
	        }
	    }
	
	    // ==============================================================
	    //      public functions
	    // ==============================================================
	
	    /**
	    * @public
	    * Handles the repositioning of the error tootip, Useful if the <code>PromptingTextInputWithError</code> is in a draggable window.
	    */
	    public function repositionError(event:*):void
	    {
	        var pt:Point = new Point(this.x, this.y);
	        pt = this.contentToGlobal(pt);
	        if( errorTip.x != pt.x + this.width + adjustErrorXPosition || errorTip.y != pt.y + adjustErrorYPosition )
	        {
	            errorTip.move( pt.x + this.width + adjustErrorXPosition, pt.y + adjustErrorYPosition );
	        }
	    }

	}
}
